#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
    This file is part of pydrop.

    pydrop is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    pydrop is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with pydrop. If not, see <http://www.gnu.org/licenses/>.

    Diese Datei ist Teil von pydrop.

    pydrop ist Freie Software: Sie können es unter den Bedingungen
    der GNU General Public License, wie von der Free Software Foundation,
    Version 3 der Lizenz oder (nach Ihrer Option) jeder späteren
    veröffentlichten Version, weiterverbreiten und/oder modifizieren.

    pydrop wird in der Hoffnung, dass es nützlich sein wird, aber
    OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
    Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
    Siehe die GNU General Public License für weitere Details.

    Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
    Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.

"""

import wx
import numpy as np
import pylab as p
import subprocess

color = []
marker = []
line = []


class TabAxes(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)

        wx.StaticText(self, -1, "X-Min:", (5,23))
        self.x_min = wx.TextCtrl(self, -1, "", (70,20), size=(60,-1))
        wx.StaticText(self, -1, "X-Max:", (165,23))
        self.x_max = wx.TextCtrl(self, -1, "", (230,20), size=(60,-1))

        wx.StaticText(self, -1, "Y-Min:", (5,63))
        self.y_min = wx.TextCtrl(self, -1, "", (70,60), size=(60,-1))
        wx.StaticText(self, -1, "Y-Max:", (165,63))
        self.y_max = wx.TextCtrl(self, -1, "", (230,60), size=(60,-1))

        wx.StaticLine(self, -1, (5, 100), (300,1))

        self.cb = wx.CheckBox(self, -1, 'Show Grid', pos=(5,120))


class TabLabels(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        wx.StaticText(self, -1, "Note: Latex in $$-environment possible!", (5,250))

        wx.StaticText(self, -1, "Caption:", (5,23))
        self.caption = wx.TextCtrl(self, -1, "", (70,20), size=(220,-1))

        wx.StaticText(self, -1, "X-Axis:", (5,63))
        self.xlabel = wx.TextCtrl(self, -1, "", (70,60), size=(220,-1))

        wx.StaticText(self, -1, "Y-Axis:", (5,103))
        self.ylabel = wx.TextCtrl(self, -1, "", (70,100), size=(220,-1))


class TabStyle(wx.Panel):
    def __init__(self, parent, list):
        wx.Panel.__init__(self, parent)

        self.list = list

        wx.StaticText(self, -1, "Line:", (5,23))
        line_list = ["None","Solid","Dashed","Dash-dot","Dotted"]
        self.linestyle = wx.ComboBox(self, 31, "None", (70,20), (220,-1), line_list, style=wx.CB_READONLY)
        self.Bind(wx.EVT_COMBOBOX, self.SetLine, id=31)

        wx.StaticText(self, -1, "Marker:", (5,63))
        marker_list = ["None","Circle","Square","Diamond","Cross","Plus","Point"]
        self.markerstyle = wx.ComboBox(self, 32, "Circle", (70,60), (220,-1), marker_list, style=wx.CB_READONLY)
        self.Bind(wx.EVT_COMBOBOX, self.SetMarker, id=32)

        wx.StaticText(self, -1, "Color:", (5,103))
        wx.Button(self, 12, 'Select', (70,100), (-1,-1))
        self.Bind(wx.EVT_BUTTON, self.SelectColor, id=12)

        dc = wx.ClientDC(parent)
        dc.DrawLine(350, 360, 190, 60)

    def SetLine(self, event):
        auswahl = self.linestyle.GetCurrentSelection()
        zeichen = ["","-","--","-.",":"]
        line[self.list.GetSelection()] = zeichen[auswahl]

    def SetMarker(self, event):
        auswahl = self.markerstyle.GetCurrentSelection()
        zeichen = ["","o","s","D","x","+","."]
        marker[self.list.GetSelection()] = zeichen[auswahl]

    def SelectColor(self, event):
        dialog = wx.ColourDialog(None)
        dialog.GetColourData().SetChooseFull(True)
        if dialog.ShowModal() == wx.ID_OK:
            data = dialog.GetColourData()
            rgb = list(data.GetColour().Get())
            color[self.list.GetSelection()] = tuple([float(rgb[0])/255,float(rgb[1])/255,float(rgb[2])/255])
        dialog.Destroy()


class TabCode(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.textfield = wx.TextCtrl(self, style=wx.TE_MULTILINE, pos=(5,5), size=(295,240))
        self.cb = wx.CheckBox(self, -1, 'Use this code for plot', pos=(5,248))

        #wx.Button(self, 11, 'r', (275,248), (25, 20))
        #self.Bind(wx.EVT_BUTTON, self.RefreshCode, id=11)

    #def RefreshCode(self, event):
        #self.textfield.WriteText(code)


class FileDropTarget(wx.FileDropTarget):
    def __init__(self, obj, parent):
        wx.FileDropTarget.__init__(self)
        self.obj = obj
        self.path = []
        self.parent = parent

    def OnDropFiles(self, x, y, filenames):
        for file in filenames:
            self.path.append(file)
        dataname = file.rpartition("/")
        #self.obj.Append("Series "+str(len(self.path))+": "+dataname[2]+"\n")
        self.obj.Append(dataname[2]+"\n")
        color.append("default")
        line.append("")
        marker.append("o")
        self.obj.SetSelection(len(self.path)-1)
        self.parent.img.Hide()


class DropHerePanel(wx.Panel):
    def __init__(self, parent):
        wx.Panel.__init__(self, parent, -1, pos=(10,50), size=(210, 210))
        self.SetBackgroundColour(wx.Colour(red=255, green=255, blue=255, alpha=wx.ALPHA_TRANSPARENT))
        bground = wx.Image('drophere.png',wx.BITMAP_TYPE_ANY)
        bground1 = wx.StaticBitmap(self, -1, wx.BitmapFromImage(bground))


class MainWindow(wx.Frame):
    def __init__(self, parent, id, title):
        wx.Frame.__init__(self, parent, id, title="PyDrop", size=(550, 350), style=wx.DEFAULT_FRAME_STYLE & ~(wx.RESIZE_BORDER | wx.RESIZE_BOX | wx.MAXIMIZE_BOX) )
        favicon = wx.Icon('icon.png', wx.BITMAP_TYPE_PNG)
        wx.Frame.SetIcon(self, favicon)

        # Sizer
        hbox = wx.BoxSizer(wx.HORIZONTAL)

        # Drop Area
        self.list = wx.ListBox(self, 26, choices=[], size=(220,310), style=wx.LB_SINGLE)
        self.fdt = FileDropTarget(self.list, self)
        self.list.SetDropTarget(self.fdt)
        hbox.Add(self.list, flag=wx.LEFT|wx.RIGHT|wx.TOP|wx.BOTTOM, border=5)

        # Notebook
        nb = wx.Notebook(self, -1, size=(305,310), style=wx.NB_TOP)
        self.tab1 = TabLabels(nb)
        self.tab2 = TabAxes(nb)
        self.tab3 = TabStyle(nb, self.list)
        #self.tab4 = TabCode(nb)

        nb.AddPage(self.tab2, 'Axes')
        nb.AddPage(self.tab1, 'Labels')
        nb.AddPage(self.tab3, 'Style')
        #nb.AddPage(self.tab4, 'Code')

        hbox.Add(nb, proportion=1, flag=wx.LEFT|wx.RIGHT|wx.TOP|wx.BOTTOM, border=5)

        # Main Buttons
        #wx.Button(self, 1, 'Plot', (235, 320), (305, -1))
        bmp = wx.Image("plot2.png", wx.BITMAP_TYPE_PNG).ConvertToBitmap()
        self.button0 = wx.BitmapButton(self, -1, bmp, pos=(235, 320), size=(305, -1))
        bmp = wx.Image("clear.png", wx.BITMAP_TYPE_PNG).ConvertToBitmap()
        self.button1 = wx.BitmapButton(self, -1, bmp, pos=(5, 320))
        bmp = wx.Image("del.png", wx.BITMAP_TYPE_PNG).ConvertToBitmap()
        self.button2 = wx.BitmapButton(self, -1, bmp, pos=(37, 320))

        #self.Bind(wx.EVT_BUTTON, self.PlotGraph, id=1)
        self.Bind(wx.EVT_BUTTON, self.PlotGraph, self.button0)
        self.Bind(wx.EVT_BUTTON, self.ClearList, self.button1)
        self.Bind(wx.EVT_BUTTON, self.DeleteItem, self.button2)

        self.Bind(wx.EVT_LISTBOX, self.SelectionChange, id=26)

		# Misc
        self.SetSizer(hbox)
        self.tab1.SetFocus()
        self.img = DropHerePanel(self)
        #self.Centre()
        self.Show()

    def PlotGraph(self, event):
        # read data
        f = open("plotgraph.py",'w')
        codestring =  "# -*- coding: utf-8 -*-\n\nimport numpy as np\nimport pylab as p\n\n"
        codestring += "paths = "+str(self.fdt.path)+"\n"
        codestring += "show_grid = "+str(self.tab2.cb.GetValue())+"\n"
        codestring += "markerlist = "+str(marker)+"\n"
        codestring += "linelist = "+str(line)+"\n"
        codestring += "colorlist = "+str(color)+"\n"
        codestring += "x_label = '"+self.tab1.xlabel.GetValue()+"'\n"
        codestring += "y_label = '"+self.tab1.ylabel.GetValue()+"'\n"
        if self.tab2.x_min.GetValue() <> "":
            codestring += "x_min = "+self.tab2.x_min.GetValue()+"\n"
        else:
            codestring += "x_min = None\n"
        if self.tab2.x_max.GetValue() <> "":
            codestring += "x_max = "+self.tab2.x_max.GetValue()+"\n"
        else:
            codestring += "x_max = None\n"
        if self.tab2.y_min.GetValue() <> "":
            codestring += "y_min = "+self.tab2.y_min.GetValue()+"\n"
        else:
            codestring += "y_min = None\n"
        if self.tab2.y_max.GetValue() <> "":
            codestring += "y_max = "+self.tab2.y_max.GetValue()+"\n"
        else:
            codestring += "y_max = None\n"
        codestring += "caption = '"+self.tab1.caption.GetValue()+"'\n"
        codestring += """

x = []
y = []

for file in paths:
    try:
        data = np.genfromtxt(file, invalid_raise=False)
    except TypeError:
        try:
            data = np.loadtxt(file)
        except:
            print "Data could not be read!"
            quit()
    L = len(data[:,0])
    x.append(data[0:L,0])
    y.append(data[0:L,1])

for i in range(len(paths)):
    if colorlist[i] == "default":
        p.plot(x[i], y[i], linestyle=linelist[i], marker=markerlist[i])
    else:
        p.plot(x[i], y[i], color=colorlist[i], linestyle=linelist[i], marker=markerlist[i])

if show_grid:
    p.grid()
p.xlabel(x_label)
p.ylabel(y_label)
p.title(caption)

if x_min == None and x_max != None:
    p.xlim(xmax=x_max)
elif x_max == None and x_min != None:
    p.xlim(xmin=x_min)
else:
    p.xlim(x_min,x_max)

if y_min == None and y_max != None:
    p.ylim(ymax=y_max)
elif y_max == None and y_min != None:
    p.ylim(ymin=y_min)
else:
    p.ylim(y_min,y_max)

p.show()
        """
        print >>f, codestring
        f.close()
        subprocess.Popen("./script.sh")

    def SelectionChange(self, event):
        #Change line combobox
        line_list = ["None","Solid","Dashed","Dash-dot","Dotted"]
        liste = ["","-","--","-.",":"]
        n = liste.index(line[self.list.GetSelection()])
        self.tab3.linestyle.SetStringSelection(line_list[n])

        #change marker combobox
        marker_list = ["None","Circle","Square","Diamond","Cross","Plus","Point"]
        liste = ["","o","s","D","x","+","."]
        n = liste.index(marker[self.list.GetSelection()])
        self.tab3.markerstyle.SetStringSelection(marker_list[n])



    def OnQuit(self, event):
        self.Close()

    def ClearList(self, event):
        self.list.Clear()
        self.fdt.path = []
        color = []
        marker = []
        line = []

    def DeleteItem(self, event):
        if len(self.fdt.path) > 1:
            n = self.list.GetSelection()
            selectedfile = self.fdt.path[n]
            self.list.Delete(n)
            del self.fdt.path[n]
            del color[n]
            del marker[n]
            del line[n]
            if n-1 > 0:
                self.list.SetSelection(n-1)
            else:
                self.list.SetSelection(0)
        elif len(self.fdt.path) == 1:
            selectedfile = self.fdt.path[0]
            self.list.Delete(0)
            del self.fdt.path[n]
            del color[0]
            del marker[0]
            del line[0]


app = wx.App()
MainWindow(None, -1, 'notebook.py')
app.MainLoop()
